import matplotlib.pyplot as plt
from numpy import where
from sklearn.datasets import make_classification
from sklearn.cluster import KMeans
from sklearn.mixture import GaussianMixture

# create dataset
num_classes = 3
X, y = make_classification(n_samples=1000, n_features=2, n_informative=2, n_redundant=0,
                           n_clusters_per_class=1, random_state=10, n_classes=num_classes)
# create scatter plot for samples from each class
for class_value in range(num_classes):
 # get row indexes for samples with this class
 row_ix = where(y == class_value)
 # create scatter of these samples
 plt.scatter(X[row_ix, 0], X[row_ix, 1])
# show plot
plt.show()

# create K-means model
num_clusters = 3  # Choose number of clusters
kmeans = KMeans(n_clusters=num_clusters)

# fit K-means model to data
kmeans.fit(X)

# get cluster labels
labels = kmeans.labels_

# get cluster centers
cluster_centers = kmeans.cluster_centers_

# visualize clustering results
plt.scatter(X[:, 0], X[:, 1], c=labels, cmap='viridis')
plt.scatter(cluster_centers[:, 0], cluster_centers[:, 1], c='red', marker='X', s=100, label='Cluster Centers')
plt.xlabel('Feature 1')
plt.ylabel('Feature 2')
plt.legend()
plt.title('K-means Clustering Results')
plt.show()

# initialize GaussianMixture with random_state=0
gmm = GaussianMixture(n_components=num_clusters, random_state=0)

# fit the GMM model to the data
gmm.fit(X)

# get cluster assignments
labels = gmm.predict(X)

# get cluster centers (means)
cluster_centers = gmm.means_

# visualize clustering results
plt.scatter(X[:, 0], X[:, 1], c=labels, cmap='viridis')
plt.scatter(cluster_centers[:, 0], cluster_centers[:, 1], c='red', marker='X', s=100, label='Cluster Centers')
plt.xlabel('Feature 1')
plt.ylabel('Feature 2')
plt.legend()
plt.title('GMM Clustering Results with 3 Clusters')
plt.show()
